==> core-v0.20.3-sources.jar: org/ice1000/jimgui/JImColumnSortSpecsGen.java <==
package org.ice1000.jimgui;

import org.ice1000.jimgui.*;
import org.ice1000.jimgui.flag.*;
import org.ice1000.jimgui.cpp.*;
import org.intellij.lang.annotations.*;
import org.jetbrains.annotations.*;
import java.nio.charset.StandardCharsets;

import static org.ice1000.jimgui.util.JImGuiUtil.*;

/**
 * @author ice1000
 * @since v0.18
 */
@SuppressWarnings("ALL")

public class JImColumnSortSpecsGen {
  /** package-private by design */
  JImColumnSortSpecsGen(long nativeObjectPtr) {
    this.nativeObjectPtr = nativeObjectPtr;
  }

  protected long nativeObjectPtr;

  public int getColumnUserID(){return getColumnUserID(nativeObjectPtr);}
  protected static native int getColumnUserID(long nativeObjectPtr);
  public void setColumnUserID(int newValue) {setColumnUserID(nativeObjectPtr, newValue);}
  protected static native void setColumnUserID(long nativeObjectPtr, int newValue);
  public int getSortDirection(){return getSortDirection(nativeObjectPtr);}
  protected static native int getSortDirection(long nativeObjectPtr);
  public void setSortDirection(int newValue) {setSortDirection(nativeObjectPtr, newValue);}
  protected static native void setSortDirection(long nativeObjectPtr, int newValue);
  public short getColumnIndex(){return getColumnIndex(nativeObjectPtr);}
  protected static native short getColumnIndex(long nativeObjectPtr);
  public void setColumnIndex(short newValue) {setColumnIndex(nativeObjectPtr, newValue);}
  protected static native void setColumnIndex(long nativeObjectPtr, short newValue);
  public short getSortOrder(){return getSortOrder(nativeObjectPtr);}
  protected static native short getSortOrder(long nativeObjectPtr);
  public void setSortOrder(short newValue) {setSortOrder(nativeObjectPtr, newValue);}
  protected static native void setSortOrder(long nativeObjectPtr, short newValue);

}

==> core-v0.21.0-sources.jar: org/ice1000/jimgui/JImColumnSortSpecsGen.java <==
package org.ice1000.jimgui;

import org.ice1000.jimgui.*;
import org.ice1000.jimgui.flag.*;
import org.ice1000.jimgui.cpp.*;
import org.intellij.lang.annotations.*;
import org.jetbrains.annotations.*;
import java.nio.charset.StandardCharsets;

import static org.ice1000.jimgui.util.JImGuiUtil.*;

/**
 * @author ice1000
 * @since v0.18
 */
@SuppressWarnings("ALL")

public class JImColumnSortSpecsGen {
  /** package-private by design */
  JImColumnSortSpecsGen(long nativeObjectPtr) {
    this.nativeObjectPtr = nativeObjectPtr;
  }

  protected long nativeObjectPtr;

  /**User+id+of+the+column+%28if+specified+by+a+TableSetupColumn%28%29+call%29*/
  public int getColumnUserID(){return getColumnUserID(nativeObjectPtr);}
  protected static native int getColumnUserID(long nativeObjectPtr);
  /**User+id+of+the+column+%28if+specified+by+a+TableSetupColumn%28%29+call%29*/
  public void setColumnUserID(int newValue) {setColumnUserID(nativeObjectPtr, newValue);}
  protected static native void setColumnUserID(long nativeObjectPtr, int newValue);
  public int getSortDirection(){return getSortDirection(nativeObjectPtr);}
  protected static native int getSortDirection(long nativeObjectPtr);
  public void setSortDirection(int newValue) {setSortDirection(nativeObjectPtr, newValue);}
  protected static native void setSortDirection(long nativeObjectPtr, int newValue);
  /**Index+of+the+column*/
  public short getColumnIndex(){return getColumnIndex(nativeObjectPtr);}
  protected static native short getColumnIndex(long nativeObjectPtr);
  /**Index+of+the+column*/
  public void setColumnIndex(short newValue) {setColumnIndex(nativeObjectPtr, newValue);}
  protected static native void setColumnIndex(long nativeObjectPtr, short newValue);
  /**Index+within+parent+ImGuiTableSortSpecs+%28always+stored+in+order+starting+from+0%2C+tables+sorted+on+a+single+criteria+will+always+have+a+0+here%29%0A++Index+of+this+column+within+sort+specs%2C+-1+if+not+sorting+on+this+column%2C+0+for+single-sort%2C+may+be+%3E0+on+multi-sort*/
  public short getSortOrder(){return getSortOrder(nativeObjectPtr);}
  protected static native short getSortOrder(long nativeObjectPtr);
  /**Index+within+parent+ImGuiTableSortSpecs+%28always+stored+in+order+starting+from+0%2C+tables+sorted+on+a+single+criteria+will+always+have+a+0+here%29%0A++Index+of+this+column+within+sort+specs%2C+-1+if+not+sorting+on+this+column%2C+0+for+single-sort%2C+may+be+%3E0+on+multi-sort*/
  public void setSortOrder(short newValue) {setSortOrder(nativeObjectPtr, newValue);}
  protected static native void setSortOrder(long nativeObjectPtr, short newValue);

}
